@@ -1,6 +1,7 @@
 # pylint: disable=unused-import,missing-docstring
 
 from deepr.examples.movielens.jobs.build_records import BuildRecords
-from deepr.examples.movielens.jobs.build_csv import BuildCSV
 from deepr.examples.movielens.jobs.predict import Predict
 from deepr.examples.movielens.jobs.evaluate import Evaluate
+from deepr.examples.movielens.jobs.init import InitCheckpoint
+from deepr.examples.movielens.jobs.svd import SVD
