@@ -1,7 +1,7 @@
 """Path Utilities"""
 
 from contextlib import contextmanager
-from typing import Union, Generator
+from typing import Union, Generator, Optional
 import os
 import pathlib
 from urllib import parse
@@ -162,7 +162,7 @@ class Path:
         LOGGER.info(f"Copying file {self} to {dest}")
         if not self.is_file(filesystem=filesystem):
             raise FileNotFoundError(str(self))
-        if self.is_hdfs:
+        if self.is_hdfs or Path(dest).is_hdfs:
             tf.io.gfile.copy(str(self), str(dest), overwrite=True)
         else:
             shutil.copy(str(self), str(dest))
@@ -198,10 +198,21 @@ class Path:
         if not self.is_hdfs:
             return (Path(path) for path in pathlib.Path(str(self)).glob(pattern))
         else:
-            return (Path(path) for path in tf.io.gfile.glob(str(Path(self, pattern))))
+
+            def _glob_rec(path, patt):
+                content = [Path(p) for p in tf.io.gfile.glob(str(Path(path, patt)))]
+                subdirs = [p for p in Path(path).iterdir() if p.is_dir()]
+                for p in subdirs:
+                    content.extend(_glob_rec(p, patt))
+                return content
+
+            if pattern.startswith("**/"):
+                return (p for p in _glob_rec(self, pattern[3:]))
+            else:
+                return (Path(p) for p in tf.io.gfile.glob(str(Path(self, pattern))))
 
     @contextmanager
-    def open(self, mode: str = "r", encoding: str = None, filesystem: FileSystem = None):
+    def open(self, mode: str = "r", encoding: Optional[str] = "utf-8", filesystem: FileSystem = None):
         """Open file on both HDFS and Local File Systems.
 
         Example
@@ -215,13 +226,15 @@ class Path:
                 file.write("Hello world!")
 
         """
+        if "b" in mode:
+            encoding = None  # mypy: ignore
         if filesystem is not None:
-            with HDFSFile(filesystem=filesystem, path=str(self), mode=mode) as file:
+            with HDFSFile(filesystem=filesystem, path=str(self), mode=mode, encoding=encoding) as file:
                 yield file
         else:
             if self.is_hdfs:
                 with HDFSFileSystem() as hdfs:
-                    with HDFSFile(filesystem=hdfs, path=str(self), mode=mode) as file:
+                    with HDFSFile(filesystem=hdfs, path=str(self), mode=mode, encoding=encoding) as file:
                         yield file
             else:
                 with pathlib.Path(str(self)).open(mode=mode, encoding=encoding) as file:
