@@ -1,6 +1,7 @@
 """Core Layers"""
 
-from typing import Tuple, List, Union
+import logging
+from typing import Tuple, List, Union, Callable
 
 import tensorflow as tf
 
@@ -8,6 +9,9 @@ from deepr.layers import base
 from deepr.utils.broadcasting import make_same_shape
 
 
+LOGGER = logging.getLogger(__name__)
+
+
 class Sum(base.Layer):
     """Sum Layer"""
 
@@ -84,7 +88,7 @@ class Dense(base.Layer):
         inputs: Union[str, Tuple[str, ...], List[str]] = None,
         outputs: Union[str, Tuple[str, ...], List[str]] = None,
         name: str = None,
-        **kwargs
+        **kwargs,
     ):
         super().__init__(n_in=1, n_out=1, inputs=inputs, outputs=outputs, name=name)
         self.units = units
@@ -94,6 +98,57 @@ class Dense(base.Layer):
         return tf.layers.dense(tensors, units=self.units, **self._kwargs)
 
 
+class DenseIndex(base.Layer):
+    """Dense Index layer.
+
+    Given a matrix A, and biases, a classical dense layer computes
+    d = activation(Ax + b), which is a vector of dimension units.
+
+    The DenseIndex layer computes only some entries of the resulting
+    vector. In other words, if
+        - indices : shape = [batch, num_indices]
+        - x : shape = [batch, d]
+    then, DenseIndex()(x, indices) returns
+        - h : shape = [batch, num_indices] with h[b, i] = d[b, indices[b, i]]
+    """
+
+    def __init__(
+        self,
+        units: int,
+        kernel_name: str,
+        bias_name: str = None,
+        activation: Callable = None,
+        reuse: bool = None,
+        trainable: bool = True,
+        **kwargs,
+    ):
+        self.units = units
+        self.kernel_name = kernel_name
+        self.bias_name = bias_name
+        self.activation = activation
+        self.reuse = reuse
+        self.trainable = trainable
+        super().__init__(n_in=2, n_out=1, **kwargs)
+
+    def forward(self, tensors, mode: str = None):
+        # pylint: disable=no-value-for-parameter
+        x, indices = tensors
+        input_dim = int(x.shape[-1])
+        shape = (self.units, input_dim)
+
+        with tf.variable_scope(tf.get_variable_scope(), reuse=self.reuse):
+            kernel_var = tf.get_variable(name=self.kernel_name, shape=shape, trainable=self.trainable)
+            rows = tf.nn.embedding_lookup(kernel_var, tf.maximum(indices, 0))
+            res = DotProduct()((x, rows))
+            if self.bias_name:
+                bias_var = tf.get_variable(name=self.bias_name, shape=(self.units,), trainable=self.trainable)
+                biases = tf.nn.embedding_lookup(bias_var, tf.maximum(indices, 0))
+                res = Add()((res, biases))
+            if self.activation is not None:
+                res = self.activation(res)
+        return res
+
+
 @base.layer(n_in=2, n_out=1)
 def Add(tensors):
     """Add two tensors of any compatible shapes."""
@@ -101,6 +156,26 @@ def Add(tensors):
     return t1 + t2
 
 
+@base.layer(n_in=2, n_out=1)
+def AddWithWeight(tensors: Tuple[tf.Tensor, tf.Tensor], start: float, end: float = None, steps: int = None):
+    """Compute loss + beta * KL, decay beta linearly during training."""
+    t1, t2 = tensors
+    if end is not None:
+        if steps is None:
+            raise ValueError(f"end = {end} but steps is None (should specify steps)")
+        LOGGER.info(f"Adding {t1} + beta * {t2} with beta decaying from {start} to {end} in {steps} steps.")
+        beta = tf.train.polynomial_decay(
+            float(start), tf.train.get_global_step(), steps, float(end), power=1.0, cycle=False
+        )
+        return t1 + beta * t2
+    elif start is not None:
+        LOGGER.info(f"Adding {t1} + {float(start)} {t2} (no decay).")
+        return t1 + float(start) * t2
+    else:
+        LOGGER.info(f"Skipping addition, returning only {t1}")
+        return t1
+
+
 @base.layer(n_in=2, n_out=1)
 def Concat(tensors, axis: int = -1):
     """Concatenate tensors on axis"""
@@ -160,7 +235,7 @@ class Conv1d(base.Layer):
         inputs: Union[str, Tuple[str, ...], List[str]] = None,
         outputs: Union[str, Tuple[str, ...], List[str]] = None,
         name: str = None,
-        **kwargs
+        **kwargs,
     ):
         super().__init__(n_in=1, n_out=1, inputs=inputs, outputs=outputs, name=name)
         self.filters = filters
@@ -176,7 +251,7 @@ class Conv1d(base.Layer):
             kernel_size=self.kernel_size,
             activation=self.activation,
             use_bias=self.use_bias,
-            **self._kwargs
+            **self._kwargs,
         )
 
 
