@@ -4,4 +4,4 @@ from deepr.prepros.base import Prepro, PreproFn, prepro
 from deepr.prepros.combinators import Serial
 from deepr.prepros.core import Map, Filter, PaddedBatch, Shuffle, Repeat, Prefetch, Take, Batch, Cache
 from deepr.prepros.lookup import TableInitializer
-from deepr.prepros.record import TFRecordSequenceExample, FromExample, ToExample
+from deepr.prepros.record import TFRecordSequenceExample, FromExample, ToExample, arrays_to_example
